
import requests
import os
import io

API = 'https://fmuvehxed0.execute-api.us-east-2.amazonaws.com/prod'
API_KEY = os.environ.get('PILLOW_TEST_API_KEY', None)

def _send_one(presigned_struct, img):
    requests.post(presigned_struct['url'],
                  data=presigned_struct['fields'],
                  files={'file':img}).raise_for_status()

def _convert(img):
    out = io.BytesIO()
    img.save(out, format='PNG')
    return out.getvalue()

def _geturls():
    req = requests.get(API+'/upload', headers={'x-api-key': API_KEY})
    req.raise_for_status()
    return req.json()

def upload(result, target):
    if not API_KEY: return

    urls = _geturls()

    _send_one(urls['upload']['result'], _convert(result))
    _send_one(urls['upload']['target'], _convert(target))

    return API + urls['display']
                        




import sys
from setuptools import setup

setup(
    name='test-image-results',
    version='0.0.2',
    packages=['test_image_results'],
    url='http://github.com/wiredfool/test-image-results',
    license='MIT',
    author='Eric Soroos',
    author_email='eric@soroos.net',
    description='Upload test images to web service ',
    long_description=open('README.rst').read() + '\n\n' + open('CHANGELOG.rst').read(),
    install_requires=['requests>=2.0.0'],
    zip_safe=False,
    keywords=['Testing', 'image'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Topic :: Software Development :: Testing',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: CPython',
    ],
)
